<a id="mypy-boto3-ecr"></a>

# mypy-boto3-ecr

[![PyPI - types-aiobotocore-ecr](https://img.shields.io/pypi/v/types-aiobotocore-ecr.svg?color=blue)](https://pypi.org/project/types-aiobotocore-ecr)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-ecr.svg?color=blue)](https://pypi.org/project/types-aiobotocore-ecr)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-ecr?color=blue)](https://pypistats.org/packages/types-aiobotocore-ecr)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.ECR 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecr.html#ECR)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-ecr docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_ecr/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-ecr](#mypy-boto3-ecr)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `ECR`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `ECR` service.

```bash
python -m pip install types-aiobotocore[ecr]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[ecr]` in your environment:
  `python -m pip install 'types-aiobotocore[ecr]'`

Both type checking and auto-complete should work for `ECR` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[ecr]` in your environment:
  `python -m pip install 'types-aiobotocore[ecr]'`

Both type checking and auto-complete should work for `ECR` service. No explicit
type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[ecr]` in your environment:
  `python -m pip install 'types-aiobotocore[ecr]'`
- Run `mypy` as usual

Type checking should work for `ECR` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[ecr]` in your environment:
  `python -m pip install 'types-aiobotocore[ecr]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ECR` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ECRClient` provides annotations for `session.create_client("ecr")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_ecr import ECRClient

session = get_session()
with async session.create_client("ecr") as client:
    client: ECRClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_ecr.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_ecr import ECRClient
from types_aiobotocore_ecr.paginator import (
    DescribeImageScanFindingsPaginator,
    DescribeImagesPaginator,
    DescribePullThroughCacheRulesPaginator,
    DescribeRepositoriesPaginator,
    GetLifecyclePolicyPreviewPaginator,
    ListImagesPaginator,
)

session = get_session()
with async session.create_client("ecr") as client:
    client: ECRClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_image_scan_findings_paginator: DescribeImageScanFindingsPaginator = client.get_paginator("describe_image_scan_findings")
        describe_images_paginator: DescribeImagesPaginator = client.get_paginator("describe_images")
        describe_pull_through_cache_rules_paginator: DescribePullThroughCacheRulesPaginator = client.get_paginator("describe_pull_through_cache_rules")
        describe_repositories_paginator: DescribeRepositoriesPaginator = client.get_paginator("describe_repositories")
        get_lifecycle_policy_preview_paginator: GetLifecyclePolicyPreviewPaginator = client.get_paginator("get_lifecycle_policy_preview")
        list_images_paginator: ListImagesPaginator = client.get_paginator("list_images")
    ```


### Waiters annotations

`types_aiobotocore_ecr.waiter` module contains type annotations for all waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_ecr.client import ECRClient
from types_aiobotocore_ecr.waiter import (
    ImageScanCompleteWaiter,
    LifecyclePolicyPreviewCompleteWaiter,
)

session = get_session()
with async session.create_client("ecr") as client:
    client: ECRClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        image_scan_complete_waiter: ImageScanCompleteWaiter = client.get_waiter("image_scan_complete")
        lifecycle_policy_preview_complete_waiter: LifecyclePolicyPreviewCompleteWaiter = client.get_waiter("lifecycle_policy_preview_complete")
    ```





<a id="literals"></a>

### Literals

`types_aiobotocore_ecr.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_ecr.literals import (
    DescribeImageScanFindingsPaginatorName,
    DescribeImagesPaginatorName,
    DescribePullThroughCacheRulesPaginatorName,
    DescribeRepositoriesPaginatorName,
    EncryptionTypeType,
    FindingSeverityType,
    GetLifecyclePolicyPreviewPaginatorName,
    ImageActionTypeType,
    ImageFailureCodeType,
    ImageScanCompleteWaiterName,
    ImageTagMutabilityType,
    LayerAvailabilityType,
    LayerFailureCodeType,
    LifecyclePolicyPreviewCompleteWaiterName,
    LifecyclePolicyPreviewStatusType,
    ListImagesPaginatorName,
    ReplicationStatusType,
    RepositoryFilterTypeType,
    ScanFrequencyType,
    ScanStatusType,
    ScanTypeType,
    ScanningConfigurationFailureCodeType,
    ScanningRepositoryFilterTypeType,
    TagStatusType,
    ServiceName,
    PaginatorName,
    WaiterName,
)

def check_value(value: DescribeImageScanFindingsPaginatorName) -> bool:
    ...
````

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_ecr.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_ecr.type_defs import (
    AttributeTypeDef,
    AuthorizationDataTypeDef,
    AwsEcrContainerImageDetailsTypeDef,
    BatchCheckLayerAvailabilityRequestRequestTypeDef,
    BatchCheckLayerAvailabilityResponseTypeDef,
    BatchDeleteImageRequestRequestTypeDef,
    BatchDeleteImageResponseTypeDef,
    BatchGetImageRequestRequestTypeDef,
    BatchGetImageResponseTypeDef,
    BatchGetRepositoryScanningConfigurationRequestRequestTypeDef,
    BatchGetRepositoryScanningConfigurationResponseTypeDef,
    CompleteLayerUploadRequestRequestTypeDef,
    CompleteLayerUploadResponseTypeDef,
    CreatePullThroughCacheRuleRequestRequestTypeDef,
    CreatePullThroughCacheRuleResponseTypeDef,
    CreateRepositoryRequestRequestTypeDef,
    CreateRepositoryResponseTypeDef,
    CvssScoreAdjustmentTypeDef,
    CvssScoreDetailsTypeDef,
    CvssScoreTypeDef,
    DeleteLifecyclePolicyRequestRequestTypeDef,
    DeleteLifecyclePolicyResponseTypeDef,
    DeletePullThroughCacheRuleRequestRequestTypeDef,
    DeletePullThroughCacheRuleResponseTypeDef,
    DeleteRegistryPolicyResponseTypeDef,
    DeleteRepositoryPolicyRequestRequestTypeDef,
    DeleteRepositoryPolicyResponseTypeDef,
    DeleteRepositoryRequestRequestTypeDef,
    DeleteRepositoryResponseTypeDef,
    DescribeImageReplicationStatusRequestRequestTypeDef,
    DescribeImageReplicationStatusResponseTypeDef,
    DescribeImageScanFindingsRequestRequestTypeDef,
    DescribeImageScanFindingsResponseTypeDef,
    DescribeImagesFilterTypeDef,
    DescribeImagesRequestRequestTypeDef,
    DescribeImagesResponseTypeDef,
    DescribePullThroughCacheRulesRequestRequestTypeDef,
    DescribePullThroughCacheRulesResponseTypeDef,
    DescribeRegistryResponseTypeDef,
    DescribeRepositoriesRequestRequestTypeDef,
    DescribeRepositoriesResponseTypeDef,
    EncryptionConfigurationTypeDef,
    EnhancedImageScanFindingTypeDef,
    GetAuthorizationTokenRequestRequestTypeDef,
    GetAuthorizationTokenResponseTypeDef,
    GetDownloadUrlForLayerRequestRequestTypeDef,
    GetDownloadUrlForLayerResponseTypeDef,
    GetLifecyclePolicyPreviewRequestRequestTypeDef,
    GetLifecyclePolicyPreviewResponseTypeDef,
    GetLifecyclePolicyRequestRequestTypeDef,
    GetLifecyclePolicyResponseTypeDef,
    GetRegistryPolicyResponseTypeDef,
    GetRegistryScanningConfigurationResponseTypeDef,
    GetRepositoryPolicyRequestRequestTypeDef,
    GetRepositoryPolicyResponseTypeDef,
    ImageDetailTypeDef,
    ImageFailureTypeDef,
    ImageIdentifierTypeDef,
    ImageReplicationStatusTypeDef,
    ImageScanFindingTypeDef,
    ImageScanFindingsSummaryTypeDef,
    ImageScanFindingsTypeDef,
    ImageScanStatusTypeDef,
    ImageScanningConfigurationTypeDef,
    ImageTypeDef,
    InitiateLayerUploadRequestRequestTypeDef,
    InitiateLayerUploadResponseTypeDef,
    LayerFailureTypeDef,
    LayerTypeDef,
    LifecyclePolicyPreviewFilterTypeDef,
    LifecyclePolicyPreviewResultTypeDef,
    LifecyclePolicyPreviewSummaryTypeDef,
    LifecyclePolicyRuleActionTypeDef,
    ListImagesFilterTypeDef,
    ListImagesRequestRequestTypeDef,
    ListImagesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    PackageVulnerabilityDetailsTypeDef,
    PaginatorConfigTypeDef,
    PullThroughCacheRuleTypeDef,
    PutImageRequestRequestTypeDef,
    PutImageResponseTypeDef,
    PutImageScanningConfigurationRequestRequestTypeDef,
    PutImageScanningConfigurationResponseTypeDef,
    PutImageTagMutabilityRequestRequestTypeDef,
    PutImageTagMutabilityResponseTypeDef,
    PutLifecyclePolicyRequestRequestTypeDef,
    PutLifecyclePolicyResponseTypeDef,
    PutRegistryPolicyRequestRequestTypeDef,
    PutRegistryPolicyResponseTypeDef,
    PutRegistryScanningConfigurationRequestRequestTypeDef,
    PutRegistryScanningConfigurationResponseTypeDef,
    PutReplicationConfigurationRequestRequestTypeDef,
    PutReplicationConfigurationResponseTypeDef,
    RecommendationTypeDef,
    RegistryScanningConfigurationTypeDef,
    RegistryScanningRuleTypeDef,
    RemediationTypeDef,
    ReplicationConfigurationTypeDef,
    ReplicationDestinationTypeDef,
    ReplicationRuleTypeDef,
    RepositoryFilterTypeDef,
    RepositoryScanningConfigurationFailureTypeDef,
    RepositoryScanningConfigurationTypeDef,
    RepositoryTypeDef,
    ResourceDetailsTypeDef,
    ResourceTypeDef,
    ResponseMetadataTypeDef,
    ScanningRepositoryFilterTypeDef,
    ScoreDetailsTypeDef,
    SetRepositoryPolicyRequestRequestTypeDef,
    SetRepositoryPolicyResponseTypeDef,
    StartImageScanRequestRequestTypeDef,
    StartImageScanResponseTypeDef,
    StartLifecyclePolicyPreviewRequestRequestTypeDef,
    StartLifecyclePolicyPreviewResponseTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
    UploadLayerPartRequestRequestTypeDef,
    UploadLayerPartResponseTypeDef,
    VulnerablePackageTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AttributeTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`types-aiobotocore-ecr` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[types-aiobotocore-ecr docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_ecr/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
